################################################################################
 # @ Author       : Pengdong Yan
 # @ Email        : yanpd01@snnu.edu.cn
 # @ Encoding     : UTF-8
 # @ Language     : shell script
 # @ Date         : 2021-11-18 00:01
# @ LastEditTime : 2021-12-09 15:17
 # @ Description  : dumux seqs and qiime2 dada2
################################################################################
## Create the conda environment and activate it
conda activate bio

## Filter out low-quality reads and remove the adaptor using fastp
    fastp \
        --in1 "18-1_FDDP210362130-1a_1.fq.gz" \
        --in2 "18-1_FDDP210362130-1a_2.fq.gz" \
        --out1 "18-1-1.fq.gz" \
        --out2 "18-1-2.fq.gz" \
        --disable_quality_filtering \
        --disable_length_filtering \
        --disable_trim_poly_g \
        --detect_adapter_for_pe \
        -h "18-1.html" \
        -j "18-1.json" \
        -w 20 

### Split the sequence using fastq-multx-----------------------------------------
# 1、Prepare the barcode file， separate the upper and lower barcodes with a “-”
# s_1    ACACGCATGACACACT-AGTGTGTCATGCGTGT
# s_2    ACACGCATGACACACT-TCTGTAGTGCGTGCGC

# 2、Download and install fastq-multx
# git clone https://github.com/brwnj/fastq-multx
# cd fastq-multx || exit
# make
# 3、Split the sequence using fastq-multx
mkdir  "normal" "rev" "merge"
    fastq-multx \
        -B barcode file.tab \
        -m 0 \
        -x \
        -b 18-1-1.fq.gz 18-1-2.fq.gz \
        -o normal/%.R1.fastq \
        -o normal/%.R2.fastq
    fastq-multx \
        -B barcode file.tab \
        -m 0 \
        -x \
        -b 18-1-2.fq.gz 18-1-1.fq.gz \
        -o rev/%.R1.fastq rev/%.R2.fastq

# ./fastq-multx/fastq-multx -B barcode_fastq.tsv -m 0 -x -b ../cl_2.fq.gz ../cl_1.fq.gz -o rev/%.R1.fastq -o rev/%.R2.fastq

# 4、Merge the above two results and abbreviate the first line
    filelist=`ls ~/ssh1/Project/normal`
    for file in $filelist;
    do
        cat normal/$file rev/$file >> merge/$file
        sed -i "s/ [^1,2].*//" merge/$file
    done

## Put the files into different folders by sample ID and build the manifest separately

mkdir 2_table-rep
filelist1=`ls ~/ssh1/Project/merge`
for file in $filelist1; 
do
	Samp="$file"
	S=${Samp:0:8}
	mkdir 2_table-rep/$S
done

rm -rf 2_table-rep/unmatche
filelist2=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist2; do
	cp  ~/ssh1/Project/merge/$file* ~/ssh1/Project/2_table-rep/$file
	Samp1="$file"
	echo "sample-id" > 2_table-rep/$file/tmp.mani.id
	echo "forward-absolute-filepath" > 2_table-rep/$file/tmp.mani.f
	echo "reverse-absolute-filepath" > 2_table-rep/$file/tmp.mani.r
	echo $Samp1 >> 2_table-rep/$file/tmp.mani.id
	find ~/ssh1/Project/2_table-rep/$file/*1.fastq >> 2_table-rep/$file/tmp.mani.f
	find ~/ssh1/Project/2_table-rep/$file/*2.fastq >> 2_table-rep/$file/tmp.mani.r
	paste 2_table-rep/$file/tmp.mani.id 2_table-rep/$file/tmp.mani.f 2_table-rep/$file/tmp.mani.r > 2_table-rep/$file/manifest
	rm -rf 2_table-rep/$file/tmp.mani.id 2_table-rep/$file/tmp.mani.f 2_table-rep/$file/tmp.mani.r
done

## qiime2 import 
conda activate qiime2
filelist3=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist3; do
	{
	qiime tools import \
        --type 'SampleData[PairedEndSequencesWithQuality]'\
        --input-format PairedEndFastqManifestPhred33V2 \
        --input-path ~/ssh1/Project/2_table-rep/$file/manifest \
        --output-path ~/ssh1/Project/2_table-rep/$file/1.demux.qza
	}
done
##  Obtain ASVs using DADA2 with denoising method
filelist4=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist4; do
	{
	qiime dada2 denoise-paired \
        --i-demultiplexed-seqs ~/ssh1/Project/2_table-rep/$file/1.demux.qza \
        --p-n-threads 80 \
        --p-max-ee-f 2 \
        --p-max-ee-r 4 \
        --p-trim-left-f 35 \
        --p-trim-left-r 35 \
        --p-trunc-len-f 0 \
        --p-trunc-len-r 0 \
        --o-table ~/ssh1/Project/2_table-rep/$file/3.table_trim_16.qza \
        --o-representative-sequences ~/ssh1/Project/2_table-rep/$file/3.rep-seqs_trim_16.qza \
        --o-denoising-stats ~/ssh1/Project/2_table-rep/$file/3.stats_trim_16.qza
	}
done
# Annotate the ASVs using the trained Classifiers
filelist5=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist5; do
  {
  qiime feature-classifier classify-sklearn \
    --i-classifier ~/ssh1/Database/Unite/classifier1.qza \
    --i-reads ~/ssh1/Project/2_table-rep/$file/3.rep-seqs_trim_16.qza \
    --o-classification ~/ssh1/Project/2_table-rep/$file/taxonomy.qza
}
done
# Visualize the results
filelist6=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist6; do
    {
        qiime metadata tabulate \
        --m-input-file ~/ssh1/Project/2_table-rep/$file/taxonomy.qza \
        --o-visualization ~/ssh1/Project/2_table-rep/$file/taxonomy.qzv
    }
done

filelist7=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist7; do
    {
        qiime metadata tabulate \
        --m-input-file ~/ssh1/Project/2_table-rep/$file/3.table_trim_16.qza \
        --o-visualization ~/ssh1/Project/2_table-rep/$file/3.table_trim_16.qzv
    }
done

filelist8=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist8; do
    {
        qiime metadata tabulate \
        --m-input-file ~/ssh1/Project/2_table-rep/$file/3.rep-seqs_trim_16.qza \
        --o-visualization ~/ssh1/Project/2_table-rep/$file/3.rep-seqs_trim_16.qzv
    }
done

filelist9=`ls ~/ssh1/Project/2_table-rep`
for file in $filelist9; do
    {
        qiime metadata tabulate \
        --m-input-file ~/ssh1/Project/2_table-rep/$file/3.stats_trim_16.qza \
        --o-visualization ~/ssh1/Project/2_table-rep/$file/3.stats_trim_16.qzv
    }
done
tar -zcvf 18-1.tar.gz 2_table-rep